@@ -2,20 +2,20 @@ from django.conf import settings
 from django.shortcuts import redirect
 from django.utils.http import urlquote
 from django.contrib.auth import REDIRECT_FIELD_NAME
-from impersonate.helpers import get_redir_path, check_allow_impersonate
+from .helpers import get_redir_path, check_allow_impersonate
 
 
 def allowed_user_required(view_func):
     def _checkuser(request, *args, **kwargs):
         if not request.user.is_authenticated():
-            return redirect('%s?%s=%s' % (
+            return redirect('{0}?{1}={2}'.format(
                 settings.LOGIN_URL,
                 REDIRECT_FIELD_NAME,
                 urlquote(request.get_full_path()),
             ))
 
         if getattr(request.user, 'is_impersonate', False):
-            # Do not allow an impersonated session to use the 
+            # Do not allow an impersonated session to use the
             # impersonate views.
             return redirect(get_redir_path())
 
