@@ -1,5 +1,12 @@
 from .helpers import check_allow_for_user, check_allow_for_uri
 
+try:
+    # Django 1.5 check
+    from django.contrib.auth import get_user_model
+except ImportError:
+    from django.contrib.auth.models import User
+else:
+    User = get_user_model()
 
 class ImpersonateMiddleware(object):
     def process_request(self, request):
@@ -8,7 +15,11 @@ class ImpersonateMiddleware(object):
 
         if request.user.is_authenticated() and \
            '_impersonate' in request.session:
-            new_user = request.session['_impersonate']
+            new_user_id = request.session['_impersonate']
+            try:
+                new_user = User.objects.get(id=new_user_id)
+            except User.DoesNotExist:
+                return
 
             if check_allow_for_user(request, new_user) and \
                check_allow_for_uri(request.path):
